@@ -224,10 +224,10 @@ qqt <- function(y,df=Inf,ylim=range(y),main="Student's t Q-Q Plot",xlab="Theoret
     invisible(list(x=x,y=y))
 }
 
-topTable <- function(fit,coef=1,number=10,genelist=NULL,adjust.method="holm",sort.by="B",resort.by=NULL)
+topTable <- function(fit,coef=1,number=10,genelist=NULL,adjust.method="BH",sort.by="B",resort.by=NULL)
 #	Summary table of top genes, object-orientated version
 #	Gordon Smyth
-#	4 August 2003.  Last modified 1 Sep 2004.
+#	4 August 2003.  Last modified 30 Sep 2005.
 {
 	fit <- unclass(fit)
 	if(!missing(genelist)) fit$genes <- genelist
@@ -242,10 +242,10 @@ topTable <- function(fit,coef=1,number=10,genelist=NULL,adjust.method="holm",sor
 		resort.by=resort.by)
 }
 
-toptable <- function(fit,coef=1,number=10,genelist=NULL,A=NULL,eb=NULL,adjust.method="holm",sort.by="B",resort.by=NULL,...)
+toptable <- function(fit,coef=1,number=10,genelist=NULL,A=NULL,eb=NULL,adjust.method="BH",sort.by="B",resort.by=NULL,...)
 #	Summary table of top genes
 #	Gordon Smyth
-#	21 Nov 2002. Last revised 28 February 2005.
+#	21 Nov 2002. Last revised 30 Sep 2005.
 {
 	if(is.null(eb)) {
 		fit$coefficients <- as.matrix(fit$coefficients)[,coef]
